@@ -1,19 +1,21 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
+import doctest
 from decimal import Decimal
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import install_module, test_depends
+from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
 from trytond.transaction import Transaction
 from trytond.exceptions import UserWarning
 
 
-class SaleCreditLimitTestCase(unittest.TestCase):
+class SaleCreditLimitTestCase(ModuleTestCase):
     'Test SaleCreditLimit module'
+    module = 'sale_credit_limit'
 
     def setUp(self):
-        install_module('sale_credit_limit')
+        super(SaleCreditLimitTestCase, self).setUp()
         self.account = POOL.get('account.account')
         self.move = POOL.get('account.move')
         self.period = POOL.get('account.period')
@@ -26,10 +28,6 @@ class SaleCreditLimitTestCase(unittest.TestCase):
         self.property = POOL.get('ir.property')
         self.model_field = POOL.get('ir.model.field')
 
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
-
     def test0010check_credit_limit(self):
         'Test check_credit_limit'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
@@ -125,7 +123,7 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.account.tests import test_account
     for test in test_account.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
         SaleCreditLimitTestCase))
